@@ -10,7 +10,7 @@ test_that("(#71) `addl` argument not throwing correct error when variable not av
                         distance = "scaled_euclidean")
   
   expect_error(bal.tab(m, addl = "race"),
-               .w("The variable \"race\" cannot be found. Be sure it is entered correctly or supply a dataset that contains this varialble to `data`."))
+               .w("The variable \"race\" cannot be found. Be sure it is entered correctly or supply a dataset that contains this varialble to `data`."), perl = TRUE)
   
   expect_no_condition(bal.tab(m, addl = "race", data = lalonde))
 })
@@ -40,7 +40,8 @@ test_that("(#76) bal.tab() doesn't produce an error with missing covariates", {
   expect_warning(
     b <- bal.tab(treat ~ age + educ + race + married + nodegree + re74 + re75,
                  data = lalonde_mis, s.d.denom = "pooled"),
-    .w("Missing values exist in the covariates. Displayed values omit these observations.")
+    .w("Missing values exist in the covariates. Displayed values omit these observations."),
+    perl = TRUE
   )
   
   expect_no_error(
@@ -67,7 +68,7 @@ test_that("(#77) no conflict with `cluster` argument to bal.tab() when {caret} i
                               s.d.denom = "pooled"))
 })
 
-test_that("(#82) love.plot() doesn't throw any ggplo2-related warnings with multiple stats", {
+test_that("(#82) love.plot() doesn't throw any ggplot2-related warnings with multiple stats", {
   skip_if_not_installed("MatchIt")
   
   data("lalonde")
@@ -95,8 +96,10 @@ test_that("(#89) love.plot() doesn't throw any error when manually removing rows
   covs <- subset(lalonde_mis, select = -c(treat, re78, nodegree, married))
   
   expect_warning({
-  b <- bal.tab(treat ~ covs, data = lalonde_mis, binary = "std", estimand = "ATE")
-  }, .w("Missing values exist in the covariates. Displayed values omit these observations"))
+    b <- bal.tab(treat ~ covs, data = lalonde_mis, binary = "std", estimand = "ATE")
+  },
+  .w("Missing values exist in the covariates. Displayed values omit these observations"),
+  perl = TRUE)
   
   b$Balance <- b$Balance[!endsWith(rownames(b$Balance), "<NA>"),]
   
